@@ -3,29 +3,8 @@ package Apache2::ASP::SessionStateManager::MySQL;
 
 use strict;
 use warnings 'all';
-
 use base 'Apache2::ASP::SessionStateManager';
 
-
-#==============================================================================
-# Returns true if the session exists and has not timed out:
-sub verify_session_id
-{
-  my ($s, $id) = @_;
-  
-  my $sth = $s->dbh->prepare(<<"");
-    SELECT COUNT(*)
-    FROM asp_sessions
-    WHERE session_id = ?
-    AND ADDTIME(modified_on, ?) >= NOW()
-
-  $sth->execute( $id, $s->{interactive_timeout} );
-  my ($active) = $sth->fetchrow();
-  $sth->finish();
-  
-  return $active;
-}# end verify_session_id()
-
 1;# return true:
 
 __END__
